@@ -35,12 +35,13 @@ import javax.inject.Inject;
 import com.google.gson.Gson;
 import com.google.gson.GsonBuilder;
 import org.dashbuilder.backend.RuntimeOptions;
+import org.dashbuilder.backend.helper.PartitionHelper;
 import org.dashbuilder.backend.navigation.RuntimeNavigationBuilder;
 import org.dashbuilder.dataset.DataSetLookup;
 import org.dashbuilder.displayer.DisplayerSettings;
 import org.dashbuilder.displayer.DisplayerType;
 import org.dashbuilder.displayer.json.DisplayerSettingsJSONMarshaller;
-import org.dashbuilder.external.service.ExternalComponentLoader;
+import org.dashbuilder.external.service.ComponentLoader;
 import org.dashbuilder.navigation.NavTree;
 import org.dashbuilder.shared.event.NewDataSetContentEvent;
 import org.dashbuilder.shared.model.DataSetContent;
@@ -52,6 +53,7 @@ import org.uberfire.ext.layout.editor.api.editor.LayoutComponent;
 import org.uberfire.ext.layout.editor.api.editor.LayoutRow;
 import org.uberfire.ext.layout.editor.api.editor.LayoutTemplate;
 
+import static org.dashbuilder.external.model.ExternalComponent.COMPONENT_ID_KEY;
 import static org.dashbuilder.external.model.ExternalComponent.COMPONENT_PARTITION_KEY;
 import static org.dashbuilder.shared.model.ImportDefinitions.DATASET_DEF_PREFIX;
 import static org.dashbuilder.shared.model.ImportDefinitions.NAVIGATION_FILE;
@@ -78,7 +80,7 @@ public class RuntimeModelParserImpl implements RuntimeModelParser {
     RuntimeModelRegistry registry;
 
     @Inject
-    ExternalComponentLoader externalComponentLoader;
+    ComponentLoader externalComponentLoader;
 
     Gson gson;
 
@@ -110,7 +112,7 @@ public class RuntimeModelParserImpl implements RuntimeModelParser {
                     continue;
                 }
                 String entryName = entry.getName();
-                
+
                 if (entryName.startsWith(DATASET_DEF_PREFIX)) {
                     datasetContents.add(retrieveDataSetContent(entry, zis));
                 }
@@ -131,7 +133,7 @@ public class RuntimeModelParserImpl implements RuntimeModelParser {
 
         if (options.isMultipleImport()) {
             if (options.isDatasetPartition()) {
-                datasetContents.forEach(ds -> ds.setId(transformId(modelId, ds.getId())));
+                datasetContents.forEach(ds -> ds.setId(PartitionHelper.partition(modelId, ds.getId())));
             }
             layoutTemplates.forEach(lt -> partitionLayoutTemplate(modelId, lt));
         }
@@ -144,16 +146,12 @@ public class RuntimeModelParserImpl implements RuntimeModelParser {
         return new RuntimeModel(navTree, layoutTemplates, System.currentTimeMillis());
     }
 
-    String transformId(String modelId, String id) {
-        return id + "| RuntimeModel=" + modelId;
-    }
-
     void extractComponentFile(String modelId, InputStream zis, String name) throws IOException {
         String externalComponentsDir = externalComponentLoader.getExternalComponentsDir();
         if (externalComponentsDir != null) {
             externalComponentsDir = externalComponentsDir.endsWith(File.separator) ? externalComponentsDir : externalComponentsDir + File.separator;
             String newFileName = null;
-            if (options.isComponentPartition()) {
+            if (options.isComponentPartition() && options.isMultipleImport()) {
                 newFileName = externalComponentsDir + modelId + File.separator + name.replaceAll(COMPONENTS_EXPORT_PATH, "");
             } else {
                 newFileName = externalComponentsDir + name.replaceAll(COMPONENTS_EXPORT_PATH, "");
@@ -200,16 +198,17 @@ public class RuntimeModelParserImpl implements RuntimeModelParser {
         } catch (Exception e) {
             throw new RuntimeException(e);
         }
-
     }
 
     private void partitionLayoutTemplate(String modelId, LayoutTemplate lt) {
         allComponentsStream(lt.getRows()).forEach(lc -> {
             String json = lc.getProperties().get("json");
+            String componentId = lc.getProperties().get(COMPONENT_ID_KEY);
             if (json != null) {
                 partitionDisplayer(lc, modelId, json);
             }
-            if (options.isComponentPartition()) {
+            // For components that does not use displayers (noData components)
+            if (options.isComponentPartition() && isExternalComponent(componentId)) {
                 lc.getProperties().put(COMPONENT_PARTITION_KEY, modelId);
             }
         });
@@ -218,16 +217,18 @@ public class RuntimeModelParserImpl implements RuntimeModelParser {
 
     private void partitionDisplayer(LayoutComponent lc, String modelId, String json) {
         DisplayerSettings settings = displayerSettingsMarshaller.fromJsonString(json);
+        String componentId = settings.getComponentId();
 
         if (options.isDatasetPartition() &&
             settings.getDataSetLookup() != null) {
             DataSetLookup dataSetLookup = settings.getDataSetLookup();
-            String newId = transformId(modelId, dataSetLookup.getDataSetUUID());
+            String newId = PartitionHelper.partition(modelId, dataSetLookup.getDataSetUUID());
             settings.getDataSetLookup().setDataSetUUID(newId);
         }
 
         if (options.isComponentPartition() &&
-            settings.getType() == DisplayerType.EXTERNAL_COMPONENT) {
+            settings.getType() == DisplayerType.EXTERNAL_COMPONENT &&
+            isExternalComponent(componentId)) {
             settings.setComponentPartition(modelId);
         }
 
@@ -241,4 +242,8 @@ public class RuntimeModelParserImpl implements RuntimeModelParser {
                                                allComponentsStream(cl.getRows())));
     }
 
+    private boolean isExternalComponent(String componentId) {
+        return externalComponentLoader.loadProvided().stream().noneMatch(c -> c.getId().equals(componentId));
+    }
+    
 }
\ No newline at end of file
