@@ -47,8 +47,8 @@ import static org.junit.Assert.assertEquals;
 import static org.junit.Assert.assertFalse;
 import static org.junit.Assert.assertTrue;
 import static org.mockito.AdditionalMatchers.or;
-import static org.mockito.Matchers.any;
-import static org.mockito.Matchers.eq;
+import static org.mockito.ArgumentMatchers.any;
+import static org.mockito.ArgumentMatchers.eq;
 import static org.mockito.Mockito.mock;
 import static org.mockito.Mockito.times;
 import static org.mockito.Mockito.verify;
@@ -269,6 +269,9 @@ public class RuntimeModelRegistryImplTest {
         keys.add(importId1);
         keys.add(importId2);
         when(runtimeModels.keySet()).thenReturn(keys);
+        
+        when(runtimeModels.remove(importId1)).thenReturn(mock(RuntimeModel.class));
+        when(runtimeModels.remove(importId2)).thenReturn(mock(RuntimeModel.class));
 
         registry.clear();
 
