@@ -27,9 +27,11 @@ import org.apache.lucene.search.MatchAllDocsQuery;
 import org.apache.lucene.search.TermQuery;
 import org.junit.Test;
 import org.uberfire.commons.async.DescriptiveThreadFactory;
+import org.uberfire.ext.metadata.engine.BatchIndexListener;
 import org.uberfire.ext.metadata.engine.Observer;
 import org.uberfire.ext.metadata.io.BatchIndex;
 import org.uberfire.ext.metadata.io.MetadataConfigBuilder;
+import org.uberfire.ext.metadata.model.KCluster;
 import org.uberfire.io.IOService;
 import org.uberfire.io.attribute.DublinCoreView;
 import org.uberfire.io.impl.IOServiceDotFileImpl;
@@ -209,10 +211,21 @@ public class BatchIndexTest extends BaseIndexTest {
                        Executors.newCachedThreadPool(new DescriptiveThreadFactory()),
                        indexersFactory(),
                        indexerDispatcherFactory(config.getIndexEngine()),
+                       new BatchIndexListener() {
+                           @Override
+                           public void notifyIndexIngStarted(KCluster kCluster, Path path) {
+
+                           }
+
+                           @Override
+                           public void notifyIndexIngFinished(KCluster kCluster, Path path) {
+
+                           }
+                       },
                        DublinCoreView.class).run(ioService().get("git://temp-repo-test/").getFileSystem(),
                                                  () -> {
                                                      try {
-                                                         final String index = toKCluster(ioService().get("git://temp-repo-test/").getFileSystem()).getClusterId();
+                                                         final String index = toKCluster(ioService().get("git://temp-repo-test/")).getClusterId();
 
                                                          {
 
